@@ -1,9 +1,9 @@
-from typing import Optional, Tuple
+from typing import Optional
 
 
 def get_authorization_scheme_param(
     authorization_header_value: Optional[str],
-) -> Tuple[str, str]:
+) -> tuple[str, str]:
     if not authorization_header_value:
         return "", ""
     scheme, _, param = authorization_header_value.partition(" ")
